Differential Operators
======================

Base class for graph convolution operators. 

.. automodule:: pycgsp.linop.diff
   :special-members: __init__

   .. autosummary::   
      GraphLaplacian
      GraphGradient
      GeneralisedGraphLaplacian


